==> 4.0.0-ISS-GKLM-FP0005-AIX.tar.gz: bin/ldap/addLDAPUserToGroup.sh <==
#!/bin/sh

printusage() {
echo "*************************************************************
Usage:
     ./addLDAPUserToGroup.sh WAS_HOME SKLM_INSTALL_HOME WAS_ADMIN WAS_PASS USER_UNIQUE_NAME SKLM_ADMIN SKLM_ADMIN_PASS
where,
WAS_HOME is the directory where WebSphere Application Server(WAS) for SKLM is installed.
SKLM_INSTALL_HOME is the directory where SKLM is installed.
WAS_ADMIN is Username of WebSphere Application Server(WAS) for SKLM.
WAS_PASS is WAS_PASS of WebSphere Application Server(WAS) for SKLM.
USER_UNIQUE_NAME is the LDAP user you want to provide SKLM Admin role.
SKLM_ADMIN is the administrator for the SKLM
SKLM_ADMIN_PASS is the password for SKLM Administrator


Example : ./addLDAPUserToGroup.sh /opt/IBM/WebSphere/AppServer /opt/IBM/SKLMV26 wasadmin password uid=001,c=in,ou=bluepages,o=ibm.com sklmamdin password

Note: -On Linux systems, addLDAPUserToGroup.sh must have executable permission.
*************************************************************"
exit 1
}

if [ $# -ne 7 ]; then
        printusage
else
   export WAS_HOME="$1"
   export SKLM_HOME="$2"
   export WAS_USER="$3"
   export WAS_PASS="$4"
   export USER_UNIQUE_NAME="$5"
   export SKLM_ADMIN="$6"	
   export SKLM_ADMIN_PASS="$7"

fi

mylog=sklmldapconf.log

if [ "$WAS_HOME" = "" ]; then
   printusage
fi
if [ "$WAS_USER" =  "" ]; then
   printusage
fi
if [ "$WAS_PASS" =  "" ]; then
   printusage
fi

if [ ! -d $WAS_HOME ]; then
echo  "Check if $WAS_HOME exists!"
exit 1
fi

if [ ! -f  $WAS_HOME/bin/stopServer.sh ]; then
echo "Check if the input provided $WAS_HOME is a valid WAS_HOME directory."
exit 1
fi

if [ ! -d $SKLM_HOME ]; then
echo "Check if $SKLM_HOME exists!"
exit 1
fi


## Add LDAP user to klmGUICLIAccessGroup and klmSecurityOfficerGroup, which needs SKLM Admin Access. 
date >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/addLDAPUserToGroup.py $USER_UNIQUE_NAME klmGUICLIAccessGroup >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "addLDAPUserToGrpGUICLI = PASS" >> ldaplog.out
else
	echo "Aborting...Add LDAP user to klmGUICLIAccessGroup failed."
        echo "addLDAPUserToGrpGUICLI = FAIL" >> ldaplog.out
        exit 1
fi


$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/addLDAPUserToGroup.py $USER_UNIQUE_NAME klmSecurityOfficerGroup >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "addLDAPUserToGrpSecOff = PASS" >> ldaplog.out
else
        echo "Aborting...Add LDAP user to klmSecurityOfficerGroup failed."
        echo "addLDAPUserToGrpSecOff = FAIL" >> ldaplog.out
        exit 1
fi

==> 4.1.0-ISS-GKLM-FP0005-AIX.tar.gz: bin/ldap/addLDAPUserToGroup.sh <==
#!/bin/sh

printusage() {
echo "*************************************************************
Usage:
     ./addLDAPUserToGroup.sh WAS_HOME SKLM_INSTALL_HOME WAS_ADMIN WAS_PASS USER_UNIQUE_NAME SKLM_ADMIN SKLM_ADMIN_PASS
where,
WAS_HOME is the directory where WebSphere Application Server(WAS) for SKLM is installed.
SKLM_INSTALL_HOME is the directory where SKLM is installed.
WAS_ADMIN is Username of WebSphere Application Server(WAS) for SKLM.
WAS_PASS is WAS_PASS of WebSphere Application Server(WAS) for SKLM.
USER_UNIQUE_NAME is the LDAP user you want to provide SKLM Admin role.
SKLM_ADMIN is the administrator for the SKLM
SKLM_ADMIN_PASS is the password for SKLM Administrator


Example : ./addLDAPUserToGroup.sh /opt/IBM/WebSphere/AppServer /opt/IBM/SKLMV26 wasadmin password uid=001,c=in,ou=bluepages,o=ibm.com sklmamdin password

Note: -On Linux systems, addLDAPUserToGroup.sh must have executable permission.
*************************************************************"
exit 1
}

if [ $# -ne 7 ]; then
        printusage
else
   export WAS_HOME="$1"
   export SKLM_HOME="$2"
   export WAS_USER="$3"
   export WAS_PASS="$4"
   export USER_UNIQUE_NAME="$5"
   export SKLM_ADMIN="$6"	
   export SKLM_ADMIN_PASS="$7"

fi

mylog=sklmldapconf.log

if [ "$WAS_HOME" = "" ]; then
   printusage
fi
if [ "$WAS_USER" =  "" ]; then
   printusage
fi
if [ "$WAS_PASS" =  "" ]; then
   printusage
fi

if [ ! -d $WAS_HOME ]; then
echo  "Check if $WAS_HOME exists!"
exit 1
fi

if [ ! -f  $WAS_HOME/bin/stopServer.sh ]; then
echo "Check if the input provided $WAS_HOME is a valid WAS_HOME directory."
exit 1
fi

if [ ! -d $SKLM_HOME ]; then
echo "Check if $SKLM_HOME exists!"
exit 1
fi


## Add LDAP user to klmGUICLIAccessGroup and klmSecurityOfficerGroup, which needs SKLM Admin Access. 
date >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/addLDAPUserToGroup.py \"$USER_UNIQUE_NAME\" klmGUICLIAccessGroup >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "addLDAPUserToGrpGUICLI = PASS" >> ldaplog.out
else
	echo "Aborting...Add LDAP user to klmGUICLIAccessGroup failed."
        echo "addLDAPUserToGrpGUICLI = FAIL" >> ldaplog.out
        exit 1
fi


$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/addLDAPUserToGroup.py \"$USER_UNIQUE_NAME\" klmSecurityOfficerGroup >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "addLDAPUserToGrpSecOff = PASS" >> ldaplog.out
else
        echo "Aborting...Add LDAP user to klmSecurityOfficerGroup failed."
        echo "addLDAPUserToGrpSecOff = FAIL" >> ldaplog.out
        exit 1
fi
